==> goldly-bundel-0.2.53.jar: public/docs.js <==
(function(){
var $$S_webly$2euser$2emarkdown$2e_95922fa5="webly.user.markdown.views",cljs$cst$keyword$div_DOT_m_DASH_6_DOT_p_DASH_6_DOT_bg_DASH_red_DASH_300_DOT_border_DASH_solid=new $APP.cljs.core.Keyword(null,"div.m-6.p-6.bg-red-300.border-solid","div.m-6.p-6.bg-red-300.border-solid",-685319393),cljs$cst$keyword$div_DOT_free_DASH_markup_DOT_prose=new $APP.cljs.core.Keyword(null,"div.free-markup.prose","div.free-markup.prose",1717833446),cljs$cst$keyword$div_DOT_flex_DOT_flex_DASH_row=new $APP.cljs.core.Keyword(null,
"div.flex.flex-row","div.flex.flex-row",209103675),cljs$cst$keyword$div_DOT_flex_DASH_none_DOT_w_DASH_24_DOT_bg_DASH_yellow_DASH_300=new $APP.cljs.core.Keyword(null,"div.flex-none.w-24.bg-yellow-300","div.flex-none.w-24.bg-yellow-300",-86054288),cljs$cst$keyword$div_DOT_flex_DASH_auto=new $APP.cljs.core.Keyword(null,"div.flex-auto","div.flex-auto",-1435035172),cljs$cst$keyword$a_DOT_b_DASH_2=new $APP.cljs.core.Keyword(null,"a.b-2","a.b-2",-1769918098);$APP.shadow.loader.set_load_start("docs");$APP.webly.user.markdown.views={};
$APP.webly.user.markdown.views.markdown=function(a){return null==a?new $APP.cljs.core.PersistentVector(null,2,5,$APP.cljs.core.PersistentVector.EMPTY_NODE,[$APP.cljs$cst$keyword$p,"Empty Markdown"],null):new $APP.cljs.core.PersistentVector(null,2,5,$APP.cljs.core.PersistentVector.EMPTY_NODE,[$APP.cljs$cst$keyword$div_DOT_gorilla_DASH_markdown,new $APP.cljs.core.PersistentArrayMap(null,1,[$APP.cljs$cst$keyword$dangerouslySetInnerHTML,new $APP.cljs.core.PersistentArrayMap(null,1,[$APP.cljs$cst$keyword$__html,
(0,$APP.module$node_modules$marked$lib$marked)(a)],null)],null)],null)};$APP.webly.user.markdown.views.markdown_view=function(a){return new $APP.cljs.core.PersistentVector(null,2,5,$APP.cljs.core.PersistentVector.EMPTY_NODE,[cljs$cst$keyword$div_DOT_free_DASH_markup_DOT_prose,new $APP.cljs.core.PersistentVector(null,2,5,$APP.cljs.core.PersistentVector.EMPTY_NODE,[$APP.webly.user.markdown.views.markdown,a],null)],null)};
$APP.webly.user.markdown.views.err=function(a,b){return new $APP.cljs.core.PersistentVector(null,3,5,$APP.cljs.core.PersistentVector.EMPTY_NODE,[cljs$cst$keyword$div_DOT_m_DASH_6_DOT_p_DASH_6_DOT_bg_DASH_red_DASH_300_DOT_border_DASH_solid,new $APP.cljs.core.PersistentVector(null,2,5,$APP.cljs.core.PersistentVector.EMPTY_NODE,[$APP.cljs$cst$keyword$h1,b],null),$APP.cljs.core.truth_(a)?new $APP.cljs.core.PersistentVector(null,2,5,$APP.cljs.core.PersistentVector.EMPTY_NODE,[$APP.cljs$cst$keyword$p,$APP.cljs.core.pr_str.cljs$core$IFn$_invoke$arity$variadic($APP.cljs.core.prim_seq.cljs$core$IFn$_invoke$arity$2([$APP.cljs$cst$keyword$error.cljs$core$IFn$_invoke$arity$1(a)],
0))],null):null],null)};
$APP.webly.user.markdown.views.markdown_viewer=function(a,b){return new $APP.cljs.core.PersistentVector(null,2,5,$APP.cljs.core.PersistentVector.EMPTY_NODE,[$APP.cljs$cst$keyword$div,null==$APP.cljs.core.deref(b)?new $APP.cljs.core.PersistentVector(null,3,5,$APP.cljs.core.PersistentVector.EMPTY_NODE,[$APP.webly.user.markdown.views.err,$APP.cljs.core.deref(b),"requesting document"],null):$APP.cljs.core._EQ_.cljs$core$IFn$_invoke$arity$2($APP.cljs$cst$keyword$markdown_SLASH_loading,$APP.cljs.core.deref(b))?
new $APP.cljs.core.PersistentVector(null,3,5,$APP.cljs.core.PersistentVector.EMPTY_NODE,[$APP.webly.user.markdown.views.err,$APP.cljs.core.deref(b),"Loading .."],null):$APP.cljs.core.truth_($APP.cljs$cst$keyword$error.cljs$core$IFn$_invoke$arity$1($APP.cljs.core.deref(b)))?new $APP.cljs.core.PersistentVector(null,3,5,$APP.cljs.core.PersistentVector.EMPTY_NODE,[$APP.webly.user.markdown.views.err,$APP.cljs.core.deref(b),"Error Loading Markdown"],null):new $APP.cljs.core.PersistentVector(null,2,5,$APP.cljs.core.PersistentVector.EMPTY_NODE,
[$APP.webly.user.markdown.views.markdown_view,$APP.cljs.core.deref(b)],null)],null)};
$APP.webly.user.markdown.views.markdown_explorer=function(a){$APP.taoensso.timbre._log_BANG_.cljs$core$IFn$_invoke$arity$11($APP.taoensso.timbre._STAR_config_STAR_,$APP.cljs$cst$keyword$info,$$S_webly$2euser$2emarkdown$2e_95922fa5,null,57,$APP.cljs$cst$keyword$p,$APP.cljs$cst$keyword$auto,new $APP.cljs.core.Delay(function(){return new $APP.cljs.core.PersistentVector(null,2,5,$APP.cljs.core.PersistentVector.EMPTY_NODE,["showing markdown file: ",a],null)},null),null,685807276,null);var b=$APP.re_frame.core.subscribe.cljs$core$IFn$_invoke$arity$1(new $APP.cljs.core.PersistentVector(null,
1,5,$APP.cljs.core.PersistentVector.EMPTY_NODE,[$APP.cljs$cst$keyword$markdown_SLASH_available],null)),c=$APP.re_frame.core.subscribe.cljs$core$IFn$_invoke$arity$1(new $APP.cljs.core.PersistentVector(null,1,5,$APP.cljs.core.PersistentVector.EMPTY_NODE,[$APP.cljs$cst$keyword$markdown_SLASH_showing_DASH_file],null)),d=$APP.re_frame.core.subscribe.cljs$core$IFn$_invoke$arity$1(new $APP.cljs.core.PersistentVector(null,1,5,$APP.cljs.core.PersistentVector.EMPTY_NODE,[$APP.cljs$cst$keyword$markdown_SLASH_showing_DASH_doc],
null));$APP.cljs.core.truth_($APP.cljs.core.truth_(a)?!$APP.cljs.core._EQ_.cljs$core$IFn$_invoke$arity$2(a,$APP.cljs.core.deref(c)):a)&&($APP.taoensso.timbre._log_BANG_.cljs$core$IFn$_invoke$arity$11($APP.taoensso.timbre._STAR_config_STAR_,$APP.cljs$cst$keyword$info,$$S_webly$2euser$2emarkdown$2e_95922fa5,null,62,$APP.cljs$cst$keyword$p,$APP.cljs$cst$keyword$auto,new $APP.cljs.core.Delay(function(){return new $APP.cljs.core.PersistentVector(null,2,5,$APP.cljs.core.PersistentVector.EMPTY_NODE,["loading markdown: ",
a],null)},null),null,842668198,null),$APP.re_frame.core.dispatch(new $APP.cljs.core.PersistentVector(null,2,5,$APP.cljs.core.PersistentVector.EMPTY_NODE,[$APP.cljs$cst$keyword$markdown_SLASH_load,a],null)));return new $APP.cljs.core.PersistentVector(null,3,5,$APP.cljs.core.PersistentVector.EMPTY_NODE,[cljs$cst$keyword$div_DOT_flex_DOT_flex_DASH_row,new $APP.cljs.core.PersistentVector(null,2,5,$APP.cljs.core.PersistentVector.EMPTY_NODE,[cljs$cst$keyword$div_DOT_flex_DASH_none_DOT_w_DASH_24_DOT_bg_DASH_yellow_DASH_300,
function(){return function g(f){return new $APP.cljs.core.LazySeq(null,function(){for(;;){var h=$APP.cljs.core.seq(f);if(h){if($APP.cljs.core.chunked_seq_QMARK_(h)){var k=$APP.cljs.core.chunk_first(h),l=$APP.cljs.core.count(k),m=$APP.cljs.core.chunk_buffer(l);a:for(var n=0;;)if(n<l){var p=$APP.cljs.core._nth(k,n);$APP.cljs.core.chunk_append(m,$APP.cljs.core.with_meta(new $APP.cljs.core.PersistentVector(null,2,5,$APP.cljs.core.PersistentVector.EMPTY_NODE,[$APP.cljs$cst$keyword$p,new $APP.cljs.core.PersistentVector(null,
3,5,$APP.cljs.core.PersistentVector.EMPTY_NODE,[cljs$cst$keyword$a_DOT_b_DASH_2,new $APP.cljs.core.PersistentArrayMap(null,1,[$APP.cljs$cst$keyword$href,["/md/",$APP.cljs.core.str.cljs$core$IFn$_invoke$arity$1(p)].join("")],null),$APP.cljs.core.subs.cljs$core$IFn$_invoke$arity$3(p,0,$APP.cljs.core.count(p)-3)],null)],null),new $APP.cljs.core.PersistentArrayMap(null,1,[$APP.cljs$cst$keyword$key,p],null)));n+=1}else{k=!0;break a}return k?$APP.cljs.core.chunk_cons($APP.cljs.core.chunk(m),g($APP.cljs.core.chunk_rest(h))):
$APP.cljs.core.chunk_cons($APP.cljs.core.chunk(m),null)}m=$APP.cljs.core.first(h);return $APP.cljs.core.cons($APP.cljs.core.with_meta(new $APP.cljs.core.PersistentVector(null,2,5,$APP.cljs.core.PersistentVector.EMPTY_NODE,[$APP.cljs$cst$keyword$p,new $APP.cljs.core.PersistentVector(null,3,5,$APP.cljs.core.PersistentVector.EMPTY_NODE,[cljs$cst$keyword$a_DOT_b_DASH_2,new $APP.cljs.core.PersistentArrayMap(null,1,[$APP.cljs$cst$keyword$href,["/md/",$APP.cljs.core.str.cljs$core$IFn$_invoke$arity$1(m)].join("")],
null),$APP.cljs.core.subs.cljs$core$IFn$_invoke$arity$3(m,0,$APP.cljs.core.count(m)-3)],null)],null),new $APP.cljs.core.PersistentArrayMap(null,1,[$APP.cljs$cst$keyword$key,m],null)),g($APP.cljs.core.rest(h)))}return null}},null,null)}($APP.cljs.core.deref(b))}()],null),new $APP.cljs.core.PersistentVector(null,2,5,$APP.cljs.core.PersistentVector.EMPTY_NODE,[cljs$cst$keyword$div_DOT_flex_DASH_auto,new $APP.cljs.core.PersistentVector(null,3,5,$APP.cljs.core.PersistentVector.EMPTY_NODE,[$APP.webly.user.markdown.views.markdown_viewer,
a,d],null)],null)],null)};$APP.webly.user.markdown.views.markdown_explorer_react=function(a){a=$APP.cljs.core.__destructure_map(a);a=$APP.cljs.core.get.cljs$core$IFn$_invoke$arity$2(a,$APP.cljs$cst$keyword$file);return new $APP.cljs.core.PersistentVector(null,2,5,$APP.cljs.core.PersistentVector.EMPTY_NODE,[$APP.webly.user.markdown.views.markdown_explorer,a],null)};$APP.shadow.loader.set_loaded();
}).call(this);

==> goldly-bundel-0.2.54.jar: public/docs.js <==
(function(){
var $$S_webly$2euser$2emarkdown$2e_95922fa5="webly.user.markdown.views",cljs$cst$keyword$div_DOT_m_DASH_6_DOT_p_DASH_6_DOT_bg_DASH_red_DASH_300_DOT_border_DASH_solid=new $APP.cljs.core.Keyword(null,"div.m-6.p-6.bg-red-300.border-solid","div.m-6.p-6.bg-red-300.border-solid",-685319393),cljs$cst$keyword$div_DOT_free_DASH_markup_DOT_prose=new $APP.cljs.core.Keyword(null,"div.free-markup.prose","div.free-markup.prose",1717833446),cljs$cst$keyword$div_DOT_flex_DOT_flex_DASH_row=new $APP.cljs.core.Keyword(null,
"div.flex.flex-row","div.flex.flex-row",209103675),cljs$cst$keyword$div_DOT_flex_DASH_none_DOT_w_DASH_24_DOT_bg_DASH_yellow_DASH_300=new $APP.cljs.core.Keyword(null,"div.flex-none.w-24.bg-yellow-300","div.flex-none.w-24.bg-yellow-300",-86054288),cljs$cst$keyword$div_DOT_flex_DASH_auto=new $APP.cljs.core.Keyword(null,"div.flex-auto","div.flex-auto",-1435035172),cljs$cst$keyword$a_DOT_b_DASH_2=new $APP.cljs.core.Keyword(null,"a.b-2","a.b-2",-1769918098);$APP.shadow.loader.set_load_start("docs");$APP.webly.user.markdown.views={};
$APP.webly.user.markdown.views.markdown=function(a){return null==a?new $APP.cljs.core.PersistentVector(null,2,5,$APP.cljs.core.PersistentVector.EMPTY_NODE,[$APP.cljs$cst$keyword$p,"Empty Markdown"],null):new $APP.cljs.core.PersistentVector(null,2,5,$APP.cljs.core.PersistentVector.EMPTY_NODE,[$APP.cljs$cst$keyword$div_DOT_gorilla_DASH_markdown,new $APP.cljs.core.PersistentArrayMap(null,1,[$APP.cljs$cst$keyword$dangerouslySetInnerHTML,new $APP.cljs.core.PersistentArrayMap(null,1,[$APP.cljs$cst$keyword$__html,
(0,$APP.module$node_modules$marked$lib$marked)(a)],null)],null)],null)};$APP.webly.user.markdown.views.markdown_view=function(a){return new $APP.cljs.core.PersistentVector(null,2,5,$APP.cljs.core.PersistentVector.EMPTY_NODE,[cljs$cst$keyword$div_DOT_free_DASH_markup_DOT_prose,new $APP.cljs.core.PersistentVector(null,2,5,$APP.cljs.core.PersistentVector.EMPTY_NODE,[$APP.webly.user.markdown.views.markdown,a],null)],null)};
$APP.webly.user.markdown.views.err=function(a,b){return new $APP.cljs.core.PersistentVector(null,3,5,$APP.cljs.core.PersistentVector.EMPTY_NODE,[cljs$cst$keyword$div_DOT_m_DASH_6_DOT_p_DASH_6_DOT_bg_DASH_red_DASH_300_DOT_border_DASH_solid,new $APP.cljs.core.PersistentVector(null,2,5,$APP.cljs.core.PersistentVector.EMPTY_NODE,[$APP.cljs$cst$keyword$h1,b],null),$APP.cljs.core.truth_(a)?new $APP.cljs.core.PersistentVector(null,2,5,$APP.cljs.core.PersistentVector.EMPTY_NODE,[$APP.cljs$cst$keyword$p,$APP.cljs.core.pr_str.cljs$core$IFn$_invoke$arity$variadic($APP.cljs.core.prim_seq.cljs$core$IFn$_invoke$arity$2([$APP.cljs$cst$keyword$error.cljs$core$IFn$_invoke$arity$1(a)],
0))],null):null],null)};
$APP.webly.user.markdown.views.markdown_viewer=function(a,b){return new $APP.cljs.core.PersistentVector(null,2,5,$APP.cljs.core.PersistentVector.EMPTY_NODE,[$APP.cljs$cst$keyword$div,null==$APP.cljs.core.deref(b)?new $APP.cljs.core.PersistentVector(null,3,5,$APP.cljs.core.PersistentVector.EMPTY_NODE,[$APP.webly.user.markdown.views.err,$APP.cljs.core.deref(b),"requesting document"],null):$APP.cljs.core._EQ_.cljs$core$IFn$_invoke$arity$2($APP.cljs$cst$keyword$markdown_SLASH_loading,$APP.cljs.core.deref(b))?
new $APP.cljs.core.PersistentVector(null,3,5,$APP.cljs.core.PersistentVector.EMPTY_NODE,[$APP.webly.user.markdown.views.err,$APP.cljs.core.deref(b),"Loading .."],null):$APP.cljs.core.truth_($APP.cljs$cst$keyword$error.cljs$core$IFn$_invoke$arity$1($APP.cljs.core.deref(b)))?new $APP.cljs.core.PersistentVector(null,3,5,$APP.cljs.core.PersistentVector.EMPTY_NODE,[$APP.webly.user.markdown.views.err,$APP.cljs.core.deref(b),"Error Loading Markdown"],null):new $APP.cljs.core.PersistentVector(null,2,5,$APP.cljs.core.PersistentVector.EMPTY_NODE,
[$APP.webly.user.markdown.views.markdown_view,$APP.cljs.core.deref(b)],null)],null)};
$APP.webly.user.markdown.views.markdown_explorer=function(a){$APP.taoensso.timbre._log_BANG_.cljs$core$IFn$_invoke$arity$11($APP.taoensso.timbre._STAR_config_STAR_,$APP.cljs$cst$keyword$info,$$S_webly$2euser$2emarkdown$2e_95922fa5,null,57,$APP.cljs$cst$keyword$p,$APP.cljs$cst$keyword$auto,new $APP.cljs.core.Delay(function(){return new $APP.cljs.core.PersistentVector(null,2,5,$APP.cljs.core.PersistentVector.EMPTY_NODE,["showing markdown file: ",a],null)},null),null,263788553,null);var b=$APP.re_frame.core.subscribe.cljs$core$IFn$_invoke$arity$1(new $APP.cljs.core.PersistentVector(null,
1,5,$APP.cljs.core.PersistentVector.EMPTY_NODE,[$APP.cljs$cst$keyword$markdown_SLASH_available],null)),c=$APP.re_frame.core.subscribe.cljs$core$IFn$_invoke$arity$1(new $APP.cljs.core.PersistentVector(null,1,5,$APP.cljs.core.PersistentVector.EMPTY_NODE,[$APP.cljs$cst$keyword$markdown_SLASH_showing_DASH_file],null)),d=$APP.re_frame.core.subscribe.cljs$core$IFn$_invoke$arity$1(new $APP.cljs.core.PersistentVector(null,1,5,$APP.cljs.core.PersistentVector.EMPTY_NODE,[$APP.cljs$cst$keyword$markdown_SLASH_showing_DASH_doc],
null));$APP.cljs.core.truth_($APP.cljs.core.truth_(a)?!$APP.cljs.core._EQ_.cljs$core$IFn$_invoke$arity$2(a,$APP.cljs.core.deref(c)):a)&&($APP.taoensso.timbre._log_BANG_.cljs$core$IFn$_invoke$arity$11($APP.taoensso.timbre._STAR_config_STAR_,$APP.cljs$cst$keyword$info,$$S_webly$2euser$2emarkdown$2e_95922fa5,null,62,$APP.cljs$cst$keyword$p,$APP.cljs$cst$keyword$auto,new $APP.cljs.core.Delay(function(){return new $APP.cljs.core.PersistentVector(null,2,5,$APP.cljs.core.PersistentVector.EMPTY_NODE,["loading markdown: ",
a],null)},null),null,-1312610705,null),$APP.re_frame.core.dispatch(new $APP.cljs.core.PersistentVector(null,2,5,$APP.cljs.core.PersistentVector.EMPTY_NODE,[$APP.cljs$cst$keyword$markdown_SLASH_load,a],null)));return new $APP.cljs.core.PersistentVector(null,3,5,$APP.cljs.core.PersistentVector.EMPTY_NODE,[cljs$cst$keyword$div_DOT_flex_DOT_flex_DASH_row,new $APP.cljs.core.PersistentVector(null,2,5,$APP.cljs.core.PersistentVector.EMPTY_NODE,[cljs$cst$keyword$div_DOT_flex_DASH_none_DOT_w_DASH_24_DOT_bg_DASH_yellow_DASH_300,
function(){return function g(f){return new $APP.cljs.core.LazySeq(null,function(){for(;;){var h=$APP.cljs.core.seq(f);if(h){if($APP.cljs.core.chunked_seq_QMARK_(h)){var k=$APP.cljs.core.chunk_first(h),l=$APP.cljs.core.count(k),m=$APP.cljs.core.chunk_buffer(l);a:for(var n=0;;)if(n<l){var p=$APP.cljs.core._nth(k,n);$APP.cljs.core.chunk_append(m,$APP.cljs.core.with_meta(new $APP.cljs.core.PersistentVector(null,2,5,$APP.cljs.core.PersistentVector.EMPTY_NODE,[$APP.cljs$cst$keyword$p,new $APP.cljs.core.PersistentVector(null,
3,5,$APP.cljs.core.PersistentVector.EMPTY_NODE,[cljs$cst$keyword$a_DOT_b_DASH_2,new $APP.cljs.core.PersistentArrayMap(null,1,[$APP.cljs$cst$keyword$href,["/md/",$APP.cljs.core.str.cljs$core$IFn$_invoke$arity$1(p)].join("")],null),$APP.cljs.core.subs.cljs$core$IFn$_invoke$arity$3(p,0,$APP.cljs.core.count(p)-3)],null)],null),new $APP.cljs.core.PersistentArrayMap(null,1,[$APP.cljs$cst$keyword$key,p],null)));n+=1}else{k=!0;break a}return k?$APP.cljs.core.chunk_cons($APP.cljs.core.chunk(m),g($APP.cljs.core.chunk_rest(h))):
$APP.cljs.core.chunk_cons($APP.cljs.core.chunk(m),null)}m=$APP.cljs.core.first(h);return $APP.cljs.core.cons($APP.cljs.core.with_meta(new $APP.cljs.core.PersistentVector(null,2,5,$APP.cljs.core.PersistentVector.EMPTY_NODE,[$APP.cljs$cst$keyword$p,new $APP.cljs.core.PersistentVector(null,3,5,$APP.cljs.core.PersistentVector.EMPTY_NODE,[cljs$cst$keyword$a_DOT_b_DASH_2,new $APP.cljs.core.PersistentArrayMap(null,1,[$APP.cljs$cst$keyword$href,["/md/",$APP.cljs.core.str.cljs$core$IFn$_invoke$arity$1(m)].join("")],
null),$APP.cljs.core.subs.cljs$core$IFn$_invoke$arity$3(m,0,$APP.cljs.core.count(m)-3)],null)],null),new $APP.cljs.core.PersistentArrayMap(null,1,[$APP.cljs$cst$keyword$key,m],null)),g($APP.cljs.core.rest(h)))}return null}},null,null)}($APP.cljs.core.deref(b))}()],null),new $APP.cljs.core.PersistentVector(null,2,5,$APP.cljs.core.PersistentVector.EMPTY_NODE,[cljs$cst$keyword$div_DOT_flex_DASH_auto,new $APP.cljs.core.PersistentVector(null,3,5,$APP.cljs.core.PersistentVector.EMPTY_NODE,[$APP.webly.user.markdown.views.markdown_viewer,
a,d],null)],null)],null)};$APP.webly.user.markdown.views.markdown_explorer_react=function(a){a=$APP.cljs.core.__destructure_map(a);a=$APP.cljs.core.get.cljs$core$IFn$_invoke$arity$2(a,$APP.cljs$cst$keyword$file);return new $APP.cljs.core.PersistentVector(null,2,5,$APP.cljs.core.PersistentVector.EMPTY_NODE,[$APP.webly.user.markdown.views.markdown_explorer,a],null)};$APP.shadow.loader.set_loaded();
}).call(this);
